@@ -15,6 +15,7 @@
 import os
 import re
 import time
+import hvac
 from datetime import datetime
 import psycopg2 as PgSQL
 from psycopg2.extras import execute_values
@@ -41,6 +42,7 @@ DBPORTS = {
 }
 
 DBPASS = {}
+DBBAOS = {}
 
 # hard coded db names for given schema names
 DBNAMES = {
@@ -103,6 +105,7 @@ SETPGDBI("SQLPATH", PgLOG.PGLOG['DSSDBHM'] + "/sql")
 SETPGDBI("VWNAME", PGDBI['DEFSC'])
 SETPGDBI("VWPORT", 0)
 SETPGDBI("VWSOCK", '')
+SETPGDBI("BAOURL", 'https://bao.k8s.ucar.edu/')
 
 PGDBI['DBSHOST'] = PgLOG.get_short_host(PGDBI['DBHOST'])
 PGDBI['DEFSHOST'] = PgLOG.get_short_host(PGDBI['DEFHOST'])
@@ -320,11 +323,12 @@ def aborttran(autocommit = True):
 #
 def record_dscheck_error(errmsg, logact = PGDBI['EXITLG']):
 
-   cnd = PgLOG.PGLOG['DSCHECK']['chkcnd']
+   check = PgLOG.PGLOG['DSCHECK']
+   chkcnd = check['chkcnd'] if 'chkcnd' in check else "cindex = {}".format(check['cindex'])
+   dflags = check['dflags'] if 'dflags' in check else ''
    if PgLOG.PGLOG['NOQUIT']: PgLOG.PGLOG['NOQUIT'] = 0
-   dflags = PgLOG.PGLOG['DSCHECK']['dflags']
 
-   pgrec = pgget("dscheck", "mcount, tcount, lockhost, pid", cnd, logact)
+   pgrec = pgget("dscheck", "mcount, tcount, lockhost, pid", chkcnd, logact)
    if not pgrec: return 0
    if not pgrec['pid'] and not pgrec['lockhost']: return 0
    (chost, cpid) = PgLOG.current_process_info()
@@ -347,7 +351,7 @@ def record_dscheck_error(errmsg, logact = PGDBI['EXITLG']):
       if pgrec['tcount'] > 1: errmsg = "Try {}: {}".format(pgrec['tcount'], errmsg)
       record['errmsg'] = errmsg
 
-   return pgupdt("dscheck", record, cnd, logact)
+   return pgupdt("dscheck", record, chkcnd, logact)
 
 #
 # local function to log query error
@@ -2228,29 +2232,76 @@ def pgname(str, sign = None):
 def get_pgpass_password():
 
    if PGDBI['PWNAME']: return PGDBI['PWNAME']
+   pwname = get_baopassword()
+   if not pwname: pwname = get_pgpassword()
+
+   return pwname
+
+def get_pgpassword():
+   
    if not DBPASS: read_pgpass()
    dbport = str(PGDBI['DBPORT']) if PGDBI['DBPORT'] else '5432'
    pwname = DBPASS.get((PGDBI['DBSHOST'], dbport, PGDBI['DBNAME'], PGDBI['LNNAME']))
    if not pwname: pwname = DBPASS.get((PGDBI['DBHOST'], dbport, PGDBI['DBNAME'], PGDBI['LNNAME']))
-
    return pwname
 
+def get_baopassword():
+
+   dbname = PGDBI['DBNAME']
+   if dbname not in DBBAOS: read_openbao()
+   return DBBAOS[dbname].get(PGDBI['LNNAME'])
+
 #
 # Reads the .pgpass file and returns a dictionary of credentials.
 #
 def read_pgpass():
 
+   pgpass = PgLOG.PGLOG['DSSHOME'] + '/.pgpass'
+   if not op.isfile(pgpass): pgpass = PgLOG.PGLOG['GDEXHOME'] + '/.pgpass'
    try:
-      with open(PgLOG.PGLOG['DSSHOME'] + '/.pgpass', "r") as f:
-         for line in f:
-            line = line.strip()
-            if not line or line.startswith("#"): continue
-            dbhost, dbport, dbname, lnname, pwname = line.split(":")
-            DBPASS[(dbhost, dbport, dbname, lnname)] = pwname
-   except FileNotFoundError:
-      with open(PgLOG.PGLOG['GDEXHOME'] + '/.pgpass', "r") as f:
+      with open(pgpass, "r") as f:
          for line in f:
             line = line.strip()
             if not line or line.startswith("#"): continue
             dbhost, dbport, dbname, lnname, pwname = line.split(":")
             DBPASS[(dbhost, dbport, dbname, lnname)] = pwname
+   except Exception as e:
+       PgLOG.pglog(str(e), PGDBI['ERRLOG'])
+
+#
+# Reads OpenBao secrets and returns a dictionary of credentials.
+#
+def read_openbao():
+
+   dbname = PGDBI['DBNAME']
+   DBBAOS[dbname] = {}
+   url = 'https://bao.k8s.ucar.edu/'
+   baopath = {
+      'ivaddb' : 'gdex/pgdb03',
+      'ispddb' : 'gdex/pgdb03',
+      'default' : 'gdex/pgdb01'
+   }
+   dbpath = baopath[dbname] if dbname in baopath else baopath['default']
+   client = hvac.Client(url=PGDBI.get('BAOURL'))
+   client.token = PgLOG.PGLOG.get('BAOTOKEN')
+   try:
+      read_response = client.secrets.kv.v2.read_secret_version(
+          path=dbpath,
+          mount_point='kv',
+          raise_on_deleted_version=False
+      )
+   except Exception as e:
+      return PgLOG.pglog(str(e), PGDBI['ERRLOG'])
+
+   baos = read_response['data']['data']
+   for key in baos:
+      ms = re.match(r'^(\w*)pass(\w*)$', key)
+      if not ms: continue
+      baoname = None
+      pre = ms.group(1)
+      suf = ms.group(2)
+      if pre:
+         baoname =  'metadata' if pre == 'meta' else pre
+      elif suf == 'word':
+         baoname = 'postgres'
+      if baoname: DBBAOS[dbname][baoname] = baos[key] 
